==> libreoffice-still-sdk-5.4.7-2-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_6.js <==
var searchData=
[
  ['galleryitem',['GalleryItem',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryItem.html',1,'com::sun::star::gallery']]],
  ['gallerytheme',['GalleryTheme',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryTheme.html',1,'com::sun::star::gallery']]],
  ['gallerythemeprovider',['GalleryThemeProvider',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryThemeProvider.html',1,'com::sun::star::gallery']]],
  ['genericclipboard',['GenericClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1GenericClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
  ['genericdrawingdocument',['GenericDrawingDocument',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawingDocument.html',1,'com::sun::star::drawing']]],
  ['genericdrawpage',['GenericDrawPage',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawPage.html',1,'com::sun::star::drawing']]],
  ['genericpropertyhandler',['GenericPropertyHandler',['../servicecom_1_1sun_1_1star_1_1inspection_1_1GenericPropertyHandler.html',1,'com::sun::star::inspection']]],
  ['generictextdocument',['GenericTextDocument',['../servicecom_1_1sun_1_1star_1_1text_1_1GenericTextDocument.html',1,'com::sun::star::text']]],
  ['getdirectpropertytolerantresult',['GetDirectPropertyTolerantResult',['../structcom_1_1sun_1_1star_1_1beans_1_1GetDirectPropertyTolerantResult.html',1,'com::sun::star::beans']]],
  ['getexpression',['GetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetExpression.html',1,'com::sun::star::text::textfield']]],
  ['getpropertytolerantresult',['GetPropertyTolerantResult',['../structcom_1_1sun_1_1star_1_1beans_1_1GetPropertyTolerantResult.html',1,'com::sun::star::beans']]],
  ['getreference',['GetReference',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html',1,'com::sun::star::text::textfield']]],
  ['giocontentprovider',['GIOContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GIOContentProvider.html',1,'com::sun::star::ucb']]],
  ['globalacceleratorconfiguration',['GlobalAcceleratorConfiguration',['../servicecom_1_1sun_1_1star_1_1ui_1_1GlobalAcceleratorConfiguration.html',1,'com::sun::star::ui']]],
  ['globaldocument',['GlobalDocument',['../servicecom_1_1sun_1_1star_1_1text_1_1GlobalDocument.html',1,'com::sun::star::text']]],
  ['globaleventbroadcaster',['GlobalEventBroadcaster',['../servicecom_1_1sun_1_1star_1_1frame_1_1GlobalEventBroadcaster.html',1,'com::sun::star::frame']]],
  ['globalsettings',['GlobalSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1GlobalSettings.html',1,'com::sun::star::text']]],
  ['globalsheetsettings',['GlobalSheetSettings',['../servicecom_1_1sun_1_1star_1_1sheet_1_1GlobalSheetSettings.html',1,'com::sun::star::sheet']]],
  ['globaltransfercommandargument',['GlobalTransferCommandArgument',['../structcom_1_1sun_1_1star_1_1ucb_1_1GlobalTransferCommandArgument.html',1,'com::sun::star::ucb']]],
  ['globaltransfercommandargument2',['GlobalTransferCommandArgument2',['../structcom_1_1sun_1_1star_1_1ucb_1_1GlobalTransferCommandArgument2.html',1,'com::sun::star::ucb']]],
  ['gluepoint',['GluePoint',['../structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint.html',1,'com::sun::star::drawing']]],
  ['gluepoint2',['GluePoint2',['../structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint2.html',1,'com::sun::star::drawing']]],
  ['gnomevfscontentprovider',['GnomeVFSContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSContentProvider.html',1,'com::sun::star::ucb']]],
  ['gnomevfsdocumentcontent',['GnomeVFSDocumentContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSDocumentContent.html',1,'com::sun::star::ucb']]],
  ['gnomevfsfoldercontent',['GnomeVFSFolderContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSFolderContent.html',1,'com::sun::star::ucb']]],
  ['goalresult',['GoalResult',['../structcom_1_1sun_1_1star_1_1sheet_1_1GoalResult.html',1,'com::sun::star::sheet']]],
  ['gradient',['Gradient',['../structcom_1_1sun_1_1star_1_1awt_1_1Gradient.html',1,'com::sun::star::awt']]],
  ['gradienttable',['GradientTable',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GradientTable.html',1,'com::sun::star::drawing']]],
  ['graphic',['Graphic',['../servicecom_1_1sun_1_1star_1_1graphic_1_1Graphic.html',1,'com::sun::star::graphic']]],
  ['graphiccrop',['GraphicCrop',['../structcom_1_1sun_1_1star_1_1text_1_1GraphicCrop.html',1,'com::sun::star::text']]],
  ['graphicdescriptor',['GraphicDescriptor',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicDescriptor.html',1,'com::sun::star::graphic']]],
  ['graphicexportfilter',['GraphicExportFilter',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicExportFilter.html',1,'com::sun::star::drawing']]],
  ['graphicfilterrequest',['GraphicFilterRequest',['../exceptioncom_1_1sun_1_1star_1_1drawing_1_1GraphicFilterRequest.html',1,'com::sun::star::drawing']]],
  ['graphicobject',['GraphicObject',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicObject.html',1,'com::sun::star::graphic']]],
  ['graphicobjectcount',['GraphicObjectCount',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GraphicObjectCount.html',1,'com::sun::star::text::textfield']]],
  ['graphicobjectresolver',['GraphicObjectResolver',['../servicecom_1_1sun_1_1star_1_1document_1_1GraphicObjectResolver.html',1,'com::sun::star::document']]],
  ['graphicobjectshape',['GraphicObjectShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicObjectShape.html',1,'GraphicObjectShape'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1GraphicObjectShape.html',1,'GraphicObjectShape']]],
  ['graphicprovider',['GraphicProvider',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicProvider.html',1,'com::sun::star::graphic']]],
  ['graphicrasterizer',['GraphicRasterizer',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicRasterizer.html',1,'com::sun::star::graphic']]],
  ['graphicrenderervcl',['GraphicRendererVCL',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicRendererVCL.html',1,'com::sun::star::graphic']]],
  ['gridcolumn',['GridColumn',['../servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridColumn.html',1,'com::sun::star::awt::grid']]],
  ['gridcolumnevent',['GridColumnEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridColumnEvent.html',1,'com::sun::star::awt::grid']]],
  ['gridcontrol',['GridControl',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1GridControl.html',1,'GridControl'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1GridControl.html',1,'GridControl']]],
  ['griddataevent',['GridDataEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridDataEvent.html',1,'com::sun::star::awt::grid']]],
  ['gridinvaliddataexception',['GridInvalidDataException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridInvalidDataException.html',1,'com::sun::star::awt::grid']]],
  ['gridinvalidmodelexception',['GridInvalidModelException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridInvalidModelException.html',1,'com::sun::star::awt::grid']]],
  ['gridproperties',['GridProperties',['../servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties.html',1,'com::sun::star::chart2']]],
  ['gridselectionevent',['GridSelectionEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html',1,'com::sun::star::awt::grid']]],
  ['group',['Group',['../servicecom_1_1sun_1_1star_1_1report_1_1Group.html',1,'Group'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html',1,'Group']]],
  ['groupaccess',['GroupAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupAccess.html',1,'com::sun::star::configuration']]],
  ['groupbox',['GroupBox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1GroupBox.html',1,'GroupBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1GroupBox.html',1,'GroupBox']]],
  ['groupdescriptor',['GroupDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1GroupDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['groupelement',['GroupElement',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupElement.html',1,'com::sun::star::configuration']]],
  ['groups',['Groups',['../servicecom_1_1sun_1_1star_1_1report_1_1Groups.html',1,'com::sun::star::report']]],
  ['groupshape',['GroupShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GroupShape.html',1,'com::sun::star::drawing']]],
  ['groupupdate',['GroupUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupUpdate.html',1,'com::sun::star::configuration']]]
];

==> libreoffice-still-sdk-6.0.6-3-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_6.js <==
var searchData=
[
  ['galleryitem',['GalleryItem',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryItem.html',1,'com::sun::star::gallery']]],
  ['gallerytheme',['GalleryTheme',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryTheme.html',1,'com::sun::star::gallery']]],
  ['gallerythemeprovider',['GalleryThemeProvider',['../servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryThemeProvider.html',1,'com::sun::star::gallery']]],
  ['genericclipboard',['GenericClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1GenericClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
  ['genericdrawingdocument',['GenericDrawingDocument',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawingDocument.html',1,'com::sun::star::drawing']]],
  ['genericdrawpage',['GenericDrawPage',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawPage.html',1,'com::sun::star::drawing']]],
  ['genericpropertyhandler',['GenericPropertyHandler',['../servicecom_1_1sun_1_1star_1_1inspection_1_1GenericPropertyHandler.html',1,'com::sun::star::inspection']]],
  ['generictextdocument',['GenericTextDocument',['../servicecom_1_1sun_1_1star_1_1text_1_1GenericTextDocument.html',1,'com::sun::star::text']]],
  ['getdirectpropertytolerantresult',['GetDirectPropertyTolerantResult',['../structcom_1_1sun_1_1star_1_1beans_1_1GetDirectPropertyTolerantResult.html',1,'com::sun::star::beans']]],
  ['getexpression',['GetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetExpression.html',1,'com::sun::star::text::textfield']]],
  ['getpropertytolerantresult',['GetPropertyTolerantResult',['../structcom_1_1sun_1_1star_1_1beans_1_1GetPropertyTolerantResult.html',1,'com::sun::star::beans']]],
  ['getreference',['GetReference',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html',1,'com::sun::star::text::textfield']]],
  ['giocontentprovider',['GIOContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GIOContentProvider.html',1,'com::sun::star::ucb']]],
  ['globalacceleratorconfiguration',['GlobalAcceleratorConfiguration',['../servicecom_1_1sun_1_1star_1_1ui_1_1GlobalAcceleratorConfiguration.html',1,'com::sun::star::ui']]],
  ['globaldocument',['GlobalDocument',['../servicecom_1_1sun_1_1star_1_1text_1_1GlobalDocument.html',1,'com::sun::star::text']]],
  ['globaleventbroadcaster',['GlobalEventBroadcaster',['../servicecom_1_1sun_1_1star_1_1frame_1_1GlobalEventBroadcaster.html',1,'com::sun::star::frame']]],
  ['globalsettings',['GlobalSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1GlobalSettings.html',1,'com::sun::star::text']]],
  ['globalsheetsettings',['GlobalSheetSettings',['../servicecom_1_1sun_1_1star_1_1sheet_1_1GlobalSheetSettings.html',1,'com::sun::star::sheet']]],
  ['globaltransfercommandargument',['GlobalTransferCommandArgument',['../structcom_1_1sun_1_1star_1_1ucb_1_1GlobalTransferCommandArgument.html',1,'com::sun::star::ucb']]],
  ['globaltransfercommandargument2',['GlobalTransferCommandArgument2',['../structcom_1_1sun_1_1star_1_1ucb_1_1GlobalTransferCommandArgument2.html',1,'com::sun::star::ucb']]],
  ['gluepoint',['GluePoint',['../structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint.html',1,'com::sun::star::drawing']]],
  ['gluepoint2',['GluePoint2',['../structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint2.html',1,'com::sun::star::drawing']]],
  ['gnomevfscontentprovider',['GnomeVFSContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSContentProvider.html',1,'com::sun::star::ucb']]],
  ['gnomevfsdocumentcontent',['GnomeVFSDocumentContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSDocumentContent.html',1,'com::sun::star::ucb']]],
  ['gnomevfsfoldercontent',['GnomeVFSFolderContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1GnomeVFSFolderContent.html',1,'com::sun::star::ucb']]],
  ['goalresult',['GoalResult',['../structcom_1_1sun_1_1star_1_1sheet_1_1GoalResult.html',1,'com::sun::star::sheet']]],
  ['gpgseinitializer',['GPGSEInitializer',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1GPGSEInitializer.html',1,'com::sun::star::xml::crypto']]],
  ['gradient',['Gradient',['../structcom_1_1sun_1_1star_1_1awt_1_1Gradient.html',1,'com::sun::star::awt']]],
  ['gradienttable',['GradientTable',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GradientTable.html',1,'com::sun::star::drawing']]],
  ['graphic',['Graphic',['../servicecom_1_1sun_1_1star_1_1graphic_1_1Graphic.html',1,'com::sun::star::graphic']]],
  ['graphiccrop',['GraphicCrop',['../structcom_1_1sun_1_1star_1_1text_1_1GraphicCrop.html',1,'com::sun::star::text']]],
  ['graphicdescriptor',['GraphicDescriptor',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicDescriptor.html',1,'com::sun::star::graphic']]],
  ['graphicexportfilter',['GraphicExportFilter',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicExportFilter.html',1,'com::sun::star::drawing']]],
  ['graphicfilterrequest',['GraphicFilterRequest',['../exceptioncom_1_1sun_1_1star_1_1drawing_1_1GraphicFilterRequest.html',1,'com::sun::star::drawing']]],
  ['graphicobject',['GraphicObject',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicObject.html',1,'com::sun::star::graphic']]],
  ['graphicobjectcount',['GraphicObjectCount',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GraphicObjectCount.html',1,'com::sun::star::text::textfield']]],
  ['graphicobjectresolver',['GraphicObjectResolver',['../servicecom_1_1sun_1_1star_1_1document_1_1GraphicObjectResolver.html',1,'com::sun::star::document']]],
  ['graphicobjectshape',['GraphicObjectShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicObjectShape.html',1,'GraphicObjectShape'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1GraphicObjectShape.html',1,'GraphicObjectShape']]],
  ['graphicprovider',['GraphicProvider',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicProvider.html',1,'com::sun::star::graphic']]],
  ['graphicrasterizer',['GraphicRasterizer',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicRasterizer.html',1,'com::sun::star::graphic']]],
  ['graphicrenderervcl',['GraphicRendererVCL',['../servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicRendererVCL.html',1,'com::sun::star::graphic']]],
  ['gridcolumn',['GridColumn',['../servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridColumn.html',1,'com::sun::star::awt::grid']]],
  ['gridcolumnevent',['GridColumnEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridColumnEvent.html',1,'com::sun::star::awt::grid']]],
  ['gridcontrol',['GridControl',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1GridControl.html',1,'GridControl'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1GridControl.html',1,'GridControl']]],
  ['griddataevent',['GridDataEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridDataEvent.html',1,'com::sun::star::awt::grid']]],
  ['gridinvaliddataexception',['GridInvalidDataException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridInvalidDataException.html',1,'com::sun::star::awt::grid']]],
  ['gridinvalidmodelexception',['GridInvalidModelException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridInvalidModelException.html',1,'com::sun::star::awt::grid']]],
  ['gridproperties',['GridProperties',['../servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties.html',1,'com::sun::star::chart2']]],
  ['gridselectionevent',['GridSelectionEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html',1,'com::sun::star::awt::grid']]],
  ['group',['Group',['../servicecom_1_1sun_1_1star_1_1report_1_1Group.html',1,'Group'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html',1,'Group']]],
  ['groupaccess',['GroupAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupAccess.html',1,'com::sun::star::configuration']]],
  ['groupbox',['GroupBox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1GroupBox.html',1,'GroupBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1GroupBox.html',1,'GroupBox']]],
  ['groupdescriptor',['GroupDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1GroupDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['groupelement',['GroupElement',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupElement.html',1,'com::sun::star::configuration']]],
  ['groups',['Groups',['../servicecom_1_1sun_1_1star_1_1report_1_1Groups.html',1,'com::sun::star::report']]],
  ['groupshape',['GroupShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1GroupShape.html',1,'com::sun::star::drawing']]],
  ['groupupdate',['GroupUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1GroupUpdate.html',1,'com::sun::star::configuration']]]
];
